# Generated by Django 5.1.7 on 2025-03-15 18:14

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="UserSession",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "session_id",
                    models.CharField(
                        db_comment="Unique identifier for the user session.",
                        help_text="A unique ID generated for each user session.",
                        max_length=255,
                        unique=True,
                        verbose_name="Session ID",
                    ),
                ),
                (
                    "user_agent",
                    models.TextField(
                        db_comment="User agent string of the user's browser.",
                        help_text="The user agent string helps identify the browser and device used.",
                        verbose_name="User Agent",
                    ),
                ),
                (
                    "ip_address",
                    models.GenericIPAddressField(
                        db_comment="IP address of the user.",
                        help_text="The IP address from which the session originated.",
                        verbose_name="IP Address",
                    ),
                ),
                (
                    "start_time",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp when the session started.",
                        help_text="The time when the user session began.",
                        verbose_name="Start Time",
                    ),
                ),
                (
                    "end_time",
                    models.DateTimeField(
                        blank=True,
                        db_comment="Timestamp when the session ended.",
                        help_text="The time when the user session ended.",
                        null=True,
                        verbose_name="End Time",
                    ),
                ),
                (
                    "user_id",
                    models.CharField(
                        blank=True,
                        db_comment="Optional identifier for the user (e.g., logged-in user ID).",
                        help_text="If the user is logged in, this field stores their unique ID.",
                        max_length=255,
                        null=True,
                        verbose_name="User ID",
                    ),
                ),
            ],
            options={
                "verbose_name": "User Session",
                "verbose_name_plural": "User Sessions",
            },
        ),
        migrations.CreateModel(
            name="UserInteraction",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "event_type",
                    models.CharField(
                        choices=[
                            ("click", "Click"),
                            ("scroll", "Scroll"),
                            ("mouse_move", "Mouse Move"),
                            ("form_submit", "Form Submit"),
                            ("input_change", "Input Change"),
                            ("page_resize", "Page Resize"),
                            ("keypress", "Key Press"),
                            ("hover", "Hover"),
                        ],
                        db_comment="Type of user interaction (e.g., click, scroll).",
                        help_text="The type of interaction performed by the user.",
                        max_length=50,
                        verbose_name="Event Type",
                    ),
                ),
                (
                    "element",
                    models.TextField(
                        db_comment="The HTML element interacted with.",
                        help_text="The ID, class, or tag name of the element the user interacted with.",
                        verbose_name="Element",
                    ),
                ),
                (
                    "timestamp",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp when the interaction occurred.",
                        help_text="The time when the interaction occurred.",
                        verbose_name="Timestamp",
                    ),
                ),
                (
                    "metadata",
                    models.JSONField(
                        blank=True,
                        db_comment="Additional data about the interaction (e.g., coordinates).",
                        default=dict,
                        help_text="Extra metadata like mouse coordinates, scroll position, etc.",
                        verbose_name="Metadata",
                    ),
                ),
                (
                    "session",
                    models.ForeignKey(
                        db_comment="The user session associated with this interaction.",
                        help_text="The user session during which this interaction occurred.",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="user_behavior.usersession",
                        verbose_name="User Session",
                    ),
                ),
            ],
            options={
                "verbose_name": "User Interaction",
                "verbose_name_plural": "User Interactions",
            },
        ),
        migrations.CreateModel(
            name="PageView",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "url",
                    models.URLField(
                        db_comment="The URL of the page viewed.",
                        help_text="The full URL of the page the user visited.",
                        verbose_name="Page URL",
                    ),
                ),
                (
                    "timestamp",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp when the page view occurred.",
                        help_text="The time when the user viewed the page.",
                        verbose_name="Timestamp",
                    ),
                ),
                (
                    "session",
                    models.ForeignKey(
                        db_comment="The session associated with this page view.",
                        help_text="The session during which this page view occurred.",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="user_behavior.usersession",
                        verbose_name="Session",
                    ),
                ),
            ],
            options={
                "verbose_name": "Page View",
                "verbose_name_plural": "Page Views",
            },
        ),
    ]
